@@ -49,6 +49,7 @@ from .document_processor_service import (
     FetchProcessorTypesResponse,
     GetEvaluationRequest,
     GetProcessorRequest,
+    GetProcessorTypeRequest,
     GetProcessorVersionRequest,
     HumanReviewStatus,
     ListEvaluationsRequest,
@@ -116,6 +117,7 @@ __all__ = (
     "FetchProcessorTypesResponse",
     "GetEvaluationRequest",
     "GetProcessorRequest",
+    "GetProcessorTypeRequest",
     "GetProcessorVersionRequest",
     "HumanReviewStatus",
     "ListEvaluationsRequest",
